charts Package
==============

:mod:`svg` Package
------------------

``svg`` is a namespace package, meant to be shared with
other libraries implementing svg functionality.

:mod:`svg.charts` Package
-------------------------

``svg.charts`` is the package containing the various
modules of this library.

:mod:`bar` Module
-----------------

.. automodule:: svg.charts.bar
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`css` Module
-----------------

.. automodule:: svg.charts.css
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`graph` Module
-------------------

.. automodule:: svg.charts.graph
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`line` Module
------------------

.. automodule:: svg.charts.line
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pie` Module
-----------------

.. automodule:: svg.charts.pie
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`plot` Module
------------------

.. automodule:: svg.charts.plot
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`schedule` Module
----------------------

.. automodule:: svg.charts.schedule
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`time_series` Module
-------------------------

.. automodule:: svg.charts.time_series
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`util` Module
------------------

.. automodule:: svg.charts.util
    :members:
    :undoc-members:
    :show-inheritance:

